@@ -10,11 +10,26 @@ from google.protobuf.descriptor import FileDescriptor
 from delphai_utils.gateway import start_gateway
 from delphai_utils.keycloak import update_public_keys
 from prometheus_client import start_http_server
-
+import functools
+from grpc.aio import AioRpcError
+from grpc import StatusCode
 from delphai_utils.interceptors.metrics import MetricsInterceptor
 from delphai_utils.interceptors.authentication import AuthenticationInterceptor
 shutdown_event = asyncio.Event()
 
+def grpc_error(func):
+  @functools.wraps(func)
+  async def wrapper(*args, **kwargs):
+    context = args[2]
+    try:
+      result = await func(*args, **kwargs)
+      return result
+    except AioRpcError as ex:
+      await context.abort(ex.code(), ex.details())
+    except Exception as ex:
+      await context.abort(StatusCode.INTERNAL, str(ex))
+
+  return wrapper
 
 def is_port_free(host, port):
   """
